@@ -8,7 +8,7 @@ mmec <- function(fixed, random, rcov, data, W,
                  verbose=TRUE, addScaleParam=NULL,
                  stepWeight=NULL, emWeight=NULL){
 
-  my.date <- "2024-07-01"
+  my.date <- "2024-11-01"
   your.date <- Sys.Date()
   ## if your month is greater than my month you are outdated
   if(dateWarning){
@@ -24,7 +24,7 @@ mmec <- function(fixed, random, rcov, data, W,
     }
     nodata <-TRUE
     cat("data argument not provided \n")
-  }else{nodata=FALSE}
+  }else{nodata=FALSE; data <- as.data.frame(data)}
 
   if(missing(rcov)){
     rcov = as.formula("~units")
